@@ -1,8 +1,8 @@
 from pydantic import Field
 from typing import Annotated, Generic, Literal, TypeGuard
 from uuid import UUID
-from maleo.schemas.mixins.identity import Identifier, Name as BaseName
-from maleo.types.string import OptStrT
+from nexo.schemas.mixins.identity import Identifier, Name as BaseName
+from nexo.types.string import OptStrT
 from ..enums.client import IdentifierType
 from ..types.client import IdentifierValueType
 
