@@ -1,6 +1,12 @@
 from pydantic import BaseModel, Field
 from typing import Annotated, Generic
-from maleo.types.uuid import OptUUIDT, OptListOfUUIDsT
+from nexo.types.uuid import OptUUIDT, OptListOfUUIDsT
+
+
+class IncludeURL(BaseModel):
+    include_url: Annotated[bool, Field(False, description="Whether to include URL")] = (
+        False
+    )
 
 
 class ClientId(BaseModel, Generic[OptUUIDT]):
