@@ -32,11 +32,13 @@ from ..enums.checkup import (
     IdentifierType,
     CheckupStatus as CheckupStatusEnum,
     OptCheckupStatus,
+    OptFeedback,
 )
 from ..mixins.common import IncludeURL, SessionId, SessionIds
 from ..mixins.checkup import (
     CheckupStatus,
     CheckupStatuses,
+    RadiologyRecordId,
     CheckupIdentifier,
 )
 from ..types.checkup import IdentifierValueType
@@ -185,18 +187,22 @@ ListOfTransitionExaminations = list[TransitionExamination]
 OptListOfTransitionExaminations = ListOfTransitionExaminations | None
 
 
-class TransitionData(BaseModel):
+class BaseTransitionData(BaseModel):
+    feedback: Annotated[OptFeedback, Field(None, description="Feedback")] = None
+
+
+class TransitionData(RadiologyRecordId, BaseTransitionData):
     examinations: Annotated[
         OptListOfTransitionExaminations,
         Field(None, description="Transition examination"),
-    ]
+    ] = None
 
 
-class FullUpdateData(CheckupStatus[CheckupStatusEnum]):
+class FullUpdateData(TransitionData, CheckupStatus[CheckupStatusEnum]):
     pass
 
 
-class PartialUpdateData(CheckupStatus[OptCheckupStatus]):
+class PartialUpdateData(TransitionData, CheckupStatus[OptCheckupStatus]):
     checkup_status: Annotated[
         OptCheckupStatus, Field(None, description="Checkup's status")
     ] = None
