@@ -1,8 +1,8 @@
 from datetime import date
-from pydantic import BaseModel, Field, computed_field
-from typing import Annotated, Generic, Literal, Self, TypeVar, overload
+from pydantic import BaseModel, Field
+from typing import Annotated, Generic, Literal, TypeVar, overload
 from uuid import UUID
-from maleo.enums.identity import (
+from nexo.enums.identity import (
     OptRhesus,
     RhesusMixin,
     OptListOfRhesuses,
@@ -17,15 +17,12 @@ from maleo.enums.identity import (
     OptListOfGenders,
     GendersMixin,
 )
-from maleo.enums.status import (
-    DataStatus,
-    SimpleDataStatusMixin,
+from nexo.enums.status import (
     ListOfDataStatuses,
     FULL_DATA_STATUSES,
 )
-from maleo.schemas.mixins.filter import convert as convert_filter
-from maleo.schemas.mixins.identity import (
-    DataIdentifier,
+from nexo.schemas.mixins.filter import convert as convert_filter
+from nexo.schemas.mixins.identity import (
     IdentifierMixin,
     Ids,
     UUIDs,
@@ -36,20 +33,19 @@ from maleo.schemas.mixins.identity import (
     UUIDUserIds,
     DateOfBirth,
 )
-from maleo.schemas.mixins.sort import convert as convert_sort
-from maleo.schemas.mixins.timestamp import LifecycleTimestamp
-from maleo.schemas.operation.enums import ResourceOperationStatusUpdateType
-from maleo.schemas.parameter import (
+from nexo.schemas.mixins.sort import convert as convert_sort
+from nexo.schemas.operation.enums import ResourceOperationStatusUpdateType
+from nexo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
     ReadPaginatedMultipleParameter,
     StatusUpdateParameter as BaseStatusUpdateParameter,
     DeleteSingleParameter as BaseDeleteSingleParameter,
 )
-from maleo.types.datetime import OptDate
-from maleo.types.dict import StrToAnyDict
-from maleo.types.integer import OptListOfInts
-from maleo.types.string import OptStr, OptListOfStrs
-from maleo.types.uuid import OptListOfUUIDs
+from nexo.types.datetime import OptDate
+from nexo.types.dict import StrToAnyDict
+from nexo.types.integer import OptListOfInts
+from nexo.types.string import OptStr, OptListOfStrs
+from nexo.types.uuid import OptListOfUUIDs
 from ..enums.patient import IdentifierType
 from ..mixins.patient import IdCard, FullName, PlaceOfBirth, PatientIdentifier
 from ..types.patient import IdentifierValueType
@@ -324,58 +320,3 @@ class DeleteSingleParameter(BaseDeleteSingleParameter[PatientIdentifier]):
         return cls(
             identifier=PatientIdentifier(type=identifier_type, value=identifier_value)
         )
-
-
-class Age(BaseModel):
-    raw: Annotated[float, Field(..., description="Age", ge=0.0)]
-    year: Annotated[int, Field(..., description="Year", ge=0)]
-    month: Annotated[int, Field(..., description="Month", ge=0)]
-    day: Annotated[int, Field(..., description="Day", ge=0)]
-
-    @classmethod
-    def from_date_of_birth(cls, date_of_birth: date) -> Self:
-        today = date.today()
-
-        # Compute Y/M/D difference
-        y = today.year - date_of_birth.year
-        m = today.month - date_of_birth.month
-        d = today.day - date_of_birth.day
-
-        # Normalize negative days/months
-        if d < 0:
-            m -= 1
-            # Approx: last month's number of days
-            # If precision needed you can use calendar.monthrange
-            prev_month = (today.month - 1) or 12
-            prev_year = today.year if today.month > 1 else today.year - 1
-            from calendar import monthrange
-
-            d += monthrange(prev_year, prev_month)[1]
-
-        if m < 0:
-            y -= 1
-            m += 12
-
-        raw = y + m / 12 + d / 365.25
-
-        return cls(raw=raw, year=y, month=m, day=d)
-
-
-class PatientSchema(
-    RhesusMixin[OptRhesus],
-    BloodTypeMixin[OptBloodType],
-    GenderMixin[Gender],
-    DateOfBirth[date],
-    PlaceOfBirth[OptStr],
-    FullName[str],
-    IdCard[str],
-    UUIDOrganizationId[UUID],
-    UUIDUserId[UUID],
-    SimpleDataStatusMixin[DataStatus],
-    LifecycleTimestamp,
-    DataIdentifier,
-):
-    @computed_field
-    @property
-    def age(self) -> Age:
-        return Age.from_date_of_birth(self.date_of_birth)
