@@ -21,6 +21,7 @@ from nexo.schemas.parameter import (
     DeleteSingleParameter as BaseDeleteSingleParameter,
 )
 from nexo.types.dict import StrToAnyDict
+from nexo.types.float import OptFloat
 from nexo.types.integer import OptListOfInts
 from nexo.types.string import OptStr
 from nexo.types.uuid import OptListOfUUIDs
@@ -53,8 +54,8 @@ class CreateParameter(
     BorderlineReactive,
     CriticalHigh,
     BorderlineHigh,
-    NormalMax,
-    NormalMin,
+    NormalMax[float],
+    NormalMin[float],
     BorderlineLow,
     CriticalLow,
     AgeRangeMixin[AgeRange],
@@ -163,8 +164,8 @@ class FullUpdateData(
     BorderlineReactive,
     CriticalHigh,
     BorderlineHigh,
-    NormalMax,
-    NormalMin,
+    NormalMax[float],
+    NormalMin[float],
     BorderlineLow,
     CriticalLow,
     AgeRangeMixin[AgeRange],
@@ -181,8 +182,8 @@ class PartialUpdateData(
     BorderlineReactive,
     CriticalHigh,
     BorderlineHigh,
-    NormalMax,
-    NormalMin,
+    NormalMax[OptFloat],
+    NormalMin[OptFloat],
     BorderlineLow,
     CriticalLow,
     AgeRangeMixin[OptAgeRange],
@@ -193,6 +194,12 @@ class PartialUpdateData(
     unit: Annotated[OptStr, Field(None, description="Rule's unit", max_length=30)] = (
         None
     )
+    normal_min: Annotated[OptFloat, Field(None, description="Normal Min", ge=0.0)] = (
+        None
+    )
+    normal_max: Annotated[OptFloat, Field(None, description="Normal Max", ge=0.0)] = (
+        None
+    )
 
 
 UpdateDataT = TypeVar("UpdateDataT", FullUpdateData, PartialUpdateData)
